# Upgrade steps from 6.10 to 6.11

## Field Type external storage

### External storage gateways

Abstract base class `eZ\Publish\Core\FieldType\StorageGateway` for the gateway of a Field Type
external storage and the `eZ\Publish\Core\FieldType\StorageGateway::setConnection` method are deprecated.

To prepare your FieldType for future storage engines and avoid using the deprecated abstract,
extend the`eZ\Publish\SPI\FieldType\StorageGateway` class and inject Database Handler directly
into the gateway instead.

Before:
```yml
app.field_type.custom_field_type.storage_gateway:
    class: CustomFieldTypeStorageGateway
    tags:
        - {name: ezpublish.fieldType.externalStorageHandler.gateway, alias: customfield, identifier: LegacyStorage}
```

```php
use eZ\Publish\Core\FieldType\StorageGateway;
use eZ\Publish\Core\Persistence\Database\DatabaseHandler;

class CustomFieldTypeStorageGateway extends StorageGateway
{
    /**
     * @var \eZ\Publish\Core\Persistence\Database\DatabaseHandler
     */
    protected $dbHandler;

    public function setConnection(DatabaseHandler $dbHandler)
    {
        $this->dbHandler = $dbHandler;
    }


    // ...
}
```

After:
```yml
app.field_type.custom_field_type.storage_gateway:
    class: CustomFieldTypeStorageGateway
    arguments:
        - "@ezpublish.api.storage_engine.legacy.dbhandler"
```

```php
use eZ\Publish\SPI\FieldType\StorageGateway;
use eZ\Publish\Core\Persistence\Database\DatabaseHandler;

class CustomFieldTypeStorageGateway extends StorageGateway
{
    /**
     * @var \eZ\Publish\Core\Persistence\Database\DatabaseHandler
     */
    protected $dbHandler;

    public function __construct(DatabaseHandler $dbHandler)
    {
        $this->dbHandler = $dbHandler;
    }

    // ...
}
```
### External storage handlers

Abstract base class `eZ\Publish\Core\FieldType\GatewayBasedStorage` for Field Type external storage
which uses gateway is deprecated.

To prepare your FieldType for future storage engines and avoid using the deprecated abstract,
use `eZ\Publish\SPI\FieldType\GatewayBasedStorage` instead and inject external
storage gateway using Dependency Injection.

Before:
```yml
app.field_type.custom_field_type.external_storage:
    class: CustomFieldTypeStorage
    tags:
        - {name: ezpublish.fieldType.externalStorageHandler, alias: customfield}
```

```php
use eZ\Publish\Core\FieldType\GatewayBasedStorage;

class CustomFieldTypeStorage extends GatewayBasedStorage
{
    public function __construct(array $gateways = [])
    {
        // ...
    }

    public function storeFieldData(VersionInfo $versionInfo, Field $field, array $context)
    {
        $this->getGateway($context)->storeFieldData($versionInfo, $field);

        // ..
    }

    public function getFieldData(VersionInfo $versionInfo, Field $field, array $context)
    {
        $this->getGateway($context)->getFieldData($versionInfo, $field);

        // ..
    }

    public function deleteFieldData(VersionInfo $versionInfo, array $fieldIds, array $context)
    {
        $this->getGateway($context)->deleteFieldData($versionInfo, $field);

        // ..
    }

    // ...
}
```

After:
```yml
app.field_type.custom_field_type.external_storage:
    class: CustomFieldTypeStorage
    arguments:
        - "@app.field_type.custom_field_type.storage_gateway"
    tags:
        - {name: ezpublish.fieldType.externalStorageHandler, alias: customfield}
```

```php
use eZ\Publish\SPI\FieldType\GatewayBasedStorage;
use eZ\Publish\SPI\FieldType\StorageGateway;

class CustomFieldTypeStorage extends GatewayBasedStorage
{
    public function __construct(StorageGateway gateway)
    {
        parent::__construct($gateway);

        // ...
    }

    public function storeFieldData(VersionInfo $versionInfo, Field $field, array $context)
    {
        $this->gateway->storeFieldData($versionInfo, $field);

        // ..
    }

    public function getFieldData(VersionInfo $versionInfo, Field $field, array $context)
    {
        $this->gateway->getFieldData($versionInfo, $field);

        // ..
    }

    public function deleteFieldData(VersionInfo $versionInfo, array $fieldIds, array $context)
    {
        $this->gateway->deleteFieldData($versionInfo, $field);

        // ..
    }

    // ...
}
```
